@@ -270,7 +270,7 @@ let finish_head resp cgi =
 
 let with_pair rex str proc =
   match Re.Pcre.extract ~rex str with
-  | [| a; b |] -> proc (a, b)
+  | [| _; a; b |] -> proc (a, b)
   | _ -> assert false
 
 let status_re = Re.Pcre.regexp "^HTTP/\\d+(?:\\.\\d+)?\\s+(\\d{3})(?:\\s+(.*?)\\s*)?$"
